import { FC, useCallback, useEffect, useState } from 'react'
import { GameSystem } from '../../types/gameSystem';
import { useObjectState } from '../../hooks/useObjectState';
import { GameSystemsService } from '../../services/game-systems';

export const GameSystemEditor: FC = () => {
  const { state: gameSystem, update: updateGameSystem, bindProperty: bindGameSystemProperty, setState: setGameSystem } = useObjectState<GameSystem>({
    id: '',
    schema: {
      id: '',
      name: '',
      templates: {},
      types: {}
    },
    schemaId: '286f4c18-d280-444b-8d7e-9a3dd09f64ef',
    name: 'Asshammer 40x a day',
    accolades: [],
  });
  const [schemas, setSchemas] = useState<[string,string][]>([]);

  const [lastSaved, setLastSaved] = useState(gameSystem);

  const fetchSchema = useCallback(async (id: string) => {
    try {
      const schema = await GameSystemsService.getSchema(id);

      updateGameSystem({
        schema
      });
    } catch (e) {
      console.log('failed to fetch schema:', e)
    }
  }, [updateGameSystem])

  useEffect(() => {
    if (gameSystem.schemaId === gameSystem.schema.id) return;
    fetchSchema(gameSystem.schemaId);
  }, [fetchSchema, gameSystem.schema.id, gameSystem.schemaId]);

  useEffect(() => {
    GameSystemsService.getSchemaList()
      .then(schemas => setSchemas(schemas));
  }, []);

  const saveGameSystem = useCallback(() => {
    GameSystemsService.saveGameSystem(gameSystem);
    setLastSaved(gameSystem);
  }, [gameSystem])

  const fetchGameSystem = useCallback(async () => {
    const gs = await GameSystemsService.getGameSystem('');
    setGameSystem(gs);
    setLastSaved(gs);
  }, [setGameSystem]);

  useEffect(() => {
    fetchGameSystem()
  // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <div className="container p-8">
      <div className="flex gap-1">
        <input className="no-default text-white bg-transparent header border-b-2 border-falcon w-1/2" type="text" {...bindGameSystemProperty('name')} placeholder="Game Name" />
        <select className="no-default text-white bg-transparent header border-b-2 border-falcon" {...bindGameSystemProperty('schemaId')}>
          <option value=""></option>
          {schemas.map(s => (
            <option value={s[0]}>{s[1]}</option>
          ))}
        </select>
        <button onClick={saveGameSystem} disabled={lastSaved === gameSystem}>Save Game System</button>
      </div>
      <div>
        <p>Accolades</p>
        <div className="grid grid-cols-3">
          {gameSystem.accolades.map(a => (
            <div>
              <p>{a.name}</p>
              <p>{a.description}</p>
            </div>
          ))}
        </div>
      </div>
    </div>
  )
}